import java.io.FileInputStream;
import java.io.FileNotFoundException;
import java.io.InputStream;

import com.silanis.esl.sdk.*;
import com.silanis.esl.sdk.builder.*;

public class fieldValidators {
	
	private static final String API_KEY = "YOUR_API_KEY_HERE";
	private static final String API_URL = "https://sandbox.e-signlive.com/api";

	public static void main(String[] args) throws FileNotFoundException {
		
		EslClient client = new EslClient(API_KEY, API_URL);
		
		InputStream fs = new FileInputStream("C:/Users/hhaidary/Desktop/pdf/sample_contract.pdf");
		
		DocumentPackage packageToSend = PackageBuilder.newPackageNamed("Sample Contract")
				.withSigner(SignerBuilder.newSignerWithEmail("john.smith@gmail.com")
						.withFirstName("John")
						.withLastName("Smith")
						.withCustomId("client")
						.signingOrder(0))
				.withSigner(SignerBuilder.newSignerWithEmail("my.email@gmail.com")
						.withFirstName("Haris")
						.withLastName("Haidary")
						.withCustomId("manager")
						.signingOrder(1))
				.withDocument(DocumentBuilder.newDocumentWithName("Contract")
						.fromStream(fs, DocumentType.PDF)
						.enableExtraction()
						.withSignature(SignatureBuilder.captureFor("my.email@gmail.com")
								.withName("manager_signature")
								.withPositionExtracted()
								.withField(FieldBuilder.signatureDate()
										.withName("manager_date")
										.withPositionExtracted()))
						.withSignature(SignatureBuilder.captureFor("john.smith@gmail.com")
								.withName("client_signature")
								.withPositionExtracted()
								.withField(FieldBuilder.signatureDate()
										.withName("client_date")
										.withPositionExtracted())
								.withField(FieldBuilder.textField()
										.withName("first_name")
										.withPositionExtracted()
										.withValidation(FieldValidatorBuilder.alphabetic().required().withErrorMessage("Please enter a valid first name.")))
								.withField(FieldBuilder.textField()
										.withName("last_name")
										.withPositionExtracted()
										.withValidation(FieldValidatorBuilder.alphabetic().required().withErrorMessage("Please enter a valid last name.")))
								.withField(FieldBuilder.textField()
										.withName("address")
										.withPositionExtracted()
										.withValidation(FieldValidatorBuilder.basic().required().withErrorMessage("Please enter a valid address.")))
								.withField(FieldBuilder.textField()
										.withName("city")
										.withPositionExtracted()
										.withValidation(FieldValidatorBuilder.alphabetic().required().withErrorMessage("Please enter a valid city.")))
								.withField(FieldBuilder.textField()
										.withName("state")
										.withPositionExtracted()
										.withValidation(FieldValidatorBuilder.alphabetic().required().maxLength(2).minLength(2).withErrorMessage("Please enter a valid state.")))
								.withField(FieldBuilder.textField()
										.withName("zip")
										.withPositionExtracted()
										.withValidation(FieldValidatorBuilder.numeric().required().maxLength(5).minLength(5).withErrorMessage("Please enter a valid zip.")))
								.withField(FieldBuilder.textField()
										.withName("country")
										.withPositionExtracted()
										.withValidation(FieldValidatorBuilder.alphabetic().required().withErrorMessage("Please enter a valid country.")))
								.withField(FieldBuilder.textField()
										.withName("phone_number")
										.withPositionExtracted()
										.withValidation(FieldValidatorBuilder.regex("^[2-9]\\d{2}-\\d{3}-\\d{4}$").required().withErrorMessage("Please enter a valid phone number (XXX-XXX-XXXX)")))
								.withField(FieldBuilder.textField()
										.withName("email")
										.withPositionExtracted()
										.withValidation(FieldValidatorBuilder.email().required().withErrorMessage("Please enter a valid email.")))
								.withField(FieldBuilder.textField()
										.withName("company")
										.withPositionExtracted()
										.withValidation(FieldValidatorBuilder.alphabetic().required().withErrorMessage("Please enter a valid company.")))
								.withField(FieldBuilder.textField()
										.withName("policy_number")
										.withPositionExtracted()
										.withValidation(FieldValidatorBuilder.numeric().required().withErrorMessage("Please enter a valid policy number.")))
								)
						)
				.build();
		
		PackageId packageId = client.createPackage(packageToSend);
		
		System.out.println(packageId);
	}

}
